@@ -127,8 +127,8 @@ class RegistryImporter(RegistrySession, WithBlobs):  # noqa: WPS214
         if not len(manifest_names):
             return None
         if preferred_manifest_name in manifest_names:
-            return Blob(self, preferred_manifest_name, digest)
-        return Blob(self, manifest_names[0], digest)
+            return Blob(self, preferred_manifest_name, digest, size=self._sizes[digest])
+        return Blob(self, manifest_names[0], digest, size=self._sizes[digest])
 
     def import_manifest(  # noqa: WPS211, WPS231
         self,
@@ -317,7 +317,7 @@ class RegistryImporter(RegistrySession, WithBlobs):  # noqa: WPS214
         for fs_layer_json in source.json.get('fsLayers'):
             layer_json = {
                 'digest': fs_layer_json['blobSum'],
-                'size': None,
+                'size': -1,
                 'mediaType': None,
             }
             self._upload_blob_if_needed(source, manifest_name, layer_json, stats=stats, dry_run=dry_run)
