@@ -25,12 +25,6 @@ from gitlabracadabra.containers.registries import ReferenceParts, Registries
 from gitlabracadabra.matchers import Matcher
 
 
-try:
-    from semantic_version import NpmSpec, Version  # noqa: WPS433
-except ImportError:
-    # semantic_version < 2.7
-    from semantic_version import Spec as NpmSpec, Version  # noqa: WPS433,WPS440
-
 if TYPE_CHECKING:
     from typing import Any, Dict, List
     from gitlabracadabra.containers.registry import Registry
@@ -90,13 +84,8 @@ class ImageMirrorsMixin(object):  # noqa: WPS214
         *,
         dry_run: bool,
     ) -> None:
-        semver = None
-        if 'semver' in image_mirror:
-            semver = NpmSpec(image_mirror.get('semver'))
-        sources = self._get_sources(image_mirror.get('from'), semver)
+        sources = self._get_sources(image_mirror.get('from'), image_mirror.get('semver'))
         for source in sources:
-            if not self._match_semver(source, semver):
-                continue
             dest = self._get_dest(
                 source[0],
                 source[1],
@@ -127,12 +116,12 @@ class ImageMirrorsMixin(object):  # noqa: WPS214
                 dry_run=dry_run,
             )
 
-    def _get_sources(self, from_param: Any, semver: Optional[NpmSpec]) -> List[Source]:
+    def _get_sources(self, from_param: Any, semver: Optional[str]) -> List[Source]:
         """Get sources.
 
         Args:
             from_param: The "from" param.
-            semver: Optional NpmSpec.
+            semver: Optional "semver" param.
 
         Returns:
             A list of tuples (base, repository, tag, digest)
@@ -150,20 +139,22 @@ class ImageMirrorsMixin(object):  # noqa: WPS214
                 [parts.manifest_name],
                 [parts.tag or default_tag],
                 parts.digest,
+                semver,
             )
         elif isinstance(from_param, dict):
             base = PurePosixPath(from_param.get('base', ''))
             repositories = from_param.get('repositories', None)
             tags = from_param.get('tags', [default_tag])
-            return self._get_sources_from_parts(base, repositories, tags, None)
+            return self._get_sources_from_parts(base, repositories, tags, None, semver)
         raise ValueError('Unexpected from param type: {0}'.format(type(from_param)))
 
-    def _get_sources_from_parts(
+    def _get_sources_from_parts(  # noqa: WPS211
         self,
         base: PurePosixPath,
         repositories: List[str],
         tags: List[str],
         digest: Optional[str],
+        semver: Optional[str],
     ) -> List[Source]:
         if not isinstance(repositories, list):
             raise ValueError('Unexpected from.repositories param type: {0}'.format(type(repositories)))
@@ -173,6 +164,7 @@ class ImageMirrorsMixin(object):  # noqa: WPS214
         for repository in repositories:
             matcher = Matcher(
                 tags,
+                semver,
                 log_prefix='[{0}] '.format(self._name),  # type: ignore
             )
             manifest = Registries().get_manifest(str(base / repository))
@@ -180,28 +172,6 @@ class ImageMirrorsMixin(object):  # noqa: WPS214
                 sources.append((base, repository, match, digest))
         return sources
 
-    def _match_semver(
-        self,
-        source: Source,
-        semver: Optional[NpmSpec],
-    ) -> bool:
-        if not semver:
-            return True
-        version_str = source[2].group(0)
-        if version_str.startswith('v'):
-            version_str = version_str[1:]
-        try:
-            version = Version(version_str)
-        except ValueError as err:
-            logger.warning(  # noqa: G200
-                '[%s] %s for %s',
-                self._name,  # type: ignore
-                str(err),
-                str(source[0] / source[1]),
-            )
-            return False
-        return version in semver
-
     def _get_dest(  # noqa: WPS211
         self,
         source_base: PurePosixPath,
