@@ -24,6 +24,7 @@ from typing import TYPE_CHECKING, List, Optional
 
 from gitlab.exceptions import GitlabCreateError, GitlabDeleteError, GitlabGetError, GitlabListError, GitlabUpdateError
 
+from jsonschema.exceptions import ValidationError
 from jsonschema.validators import validator_for
 
 from gitlabracadabra.gitlab.connections import GitlabConnections
@@ -68,7 +69,7 @@ class GitLabracadabraObject(object):
         validator_class = validator_for(self.SCHEMA)
         validator_class.check_schema(self.SCHEMA)
         validator = validator_class(self.SCHEMA)
-        self._errors = sorted(validator.iter_errors(content), key=lambda e: e.path)
+        self._errors: list[ValidationError] = sorted(validator.iter_errors(content), key=lambda e: e.path)
         self._gitlab_id = self._content.pop('gitlab_id', None)
         self._create_object = self._content.pop('create_object', None)
         self._delete_object = self._content.pop('delete_object', None)
@@ -89,7 +90,7 @@ class GitLabracadabraObject(object):
     def registry_auth_info(self) -> AuthInfo:
         return self.connection.registry_auth_info
 
-    def errors(self):
+    def errors(self) -> list[ValidationError]:
         return self._errors
 
     """"type_name()
